@@ -26,8 +26,15 @@ class Where(sqlparse.sql.TokenList):
 
 sqlparse.sql.Where = Where
 
-KEYWORDS_COMMON['FORMAT'] = tokens.Keyword.DML
-SQL_REGEX = {'clickhouse-ext': [('FORMAT', sqlparse.tokens.Keyword)]}
+KEYWORDS_COMMON['FORMAT'] = tokens.Keyword
+KEYWORDS_COMMON['DESCRIBE'] = tokens.Keyword.DML
+KEYWORDS_COMMON['SHOW'] = tokens.Keyword.DML
+SQL_REGEX = {
+    'clickhouse-ext': [
+        ('FORMAT\b', sqlparse.tokens.Keyword),
+        ('(DESCRIBE|SHOW)\b', sqlparse.tokens.Keyword.DML),
+    ]
+}
 
 FLAGS = re.IGNORECASE | re.UNICODE
 SQL_REGEX = [
